#!/bin/bash
#
# Copyright:
# ----------------------------------------------------------------------------
# This confidential and proprietary software may be used only as authorized
# by a licensing agreement from ARM Limited.
#      (C) COPYRIGHT 2016-2019 ARM Limited, ALL RIGHTS RESERVED
# The entire notice above must be reproduced on all authorized copies and
# copies may only be made to the extent permitted by a licensing agreement
# from ARM Limited.
# ----------------------------------------------------------------------------

# Some subtleties:
#
# * Calling bootstrap_linux with an absolute path means SRCDIR is
#   absolute, and you can thus move BUILDDIR
#   independently of SRCDIR.
#   - this doesn't work
#
# * Calling bootstrap_linux with a relative path means SRCDIR is
#   relative, and you can move SRCDIR and BUILDDIR together.
#
# Both of the above depend on the ninja rules being written correctly.

set -e

SCRIPT_DIR="$(dirname "${BASH_SOURCE[0]}")"

# Select a BUILDDIR if not provided one
if [[ -z "$BUILDDIR" ]]; then
    echo "BUILDDIR is not set - using build"
    BUILDDIR=build
fi

# Create the build directory. The 'relative_path' helper can only be used on
# existing directories.
mkdir -p "$BUILDDIR"

source "${SCRIPT_DIR}/bob/pathtools.bash"

ORIG_BUILDDIR="${BUILDDIR}"

SRCDIR="$(dirname "${SCRIPT_DIR}")"
if [ "${BUILDDIR:0:1}" != '/' ]; then
    # Redo SRCDIR to be relative to BUILDDIR
    SRCDIR="$(relative_path "${BUILDDIR}" "${SRCDIR}")"
    BUILDDIR=.
else
    SRCDIR="$(bob_realpath "${SRCDIR}")"
fi

# Move to the build directory - we want this to be the working directory of the build
cd "${ORIG_BUILDDIR}"

# Set variables to bootstrap Bob.
export TOPNAME="build.bp"
export BLUEPRINT_LIST_FILE=".bplist"
export CONFIGNAME="mali.config"
export BOB_CONFIG_OPTS="--ignore-missing"
export BOB_CONFIG_PLUGINS="${SRCDIR}/bldsys/tools/kernel_explore ${SRCDIR}/bldsys/tools/tools_checker_plugin ${SRCDIR}/bldsys/tools/ddk_host_explore ${SRCDIR}/bldsys/tools/config_warnings"
export SRCDIR
export BUILDDIR

"${SRCDIR}/bldsys/bob/bootstrap_linux.bash"

# Pick up some info that bob has worked out
BOOTSTRAP=".bob.bootstrap"
source "${BOOTSTRAP}"

# Setup the DDK build script
if [ "${SRCDIR}" == "." ]; then
    # Use a simplified link
    ln -sf "bldsys/buildme.bash" "buildme"
else
    ln -sf "${SRCDIR}/bldsys/buildme.bash" "buildme"
fi

# Print info for users
echo "To configure the build directory, run ${ORIG_BUILDDIR}/config ARGS"
echo "Then build with ${ORIG_BUILDDIR}/buildme"
